import request from "@/utils/request";
const api = "/mosty-api/mosty-jcgl";
//分页查询
export function getDsfList(params) {
    return request({
        url: api + '/dsf',
        method: 'GET',
        params
    })
}

//新增
export function addDsf(data) {
    return request({
        url: api + '/dsf',
        method: "post",
        data
    })
}
//修改
export function putDsf(data) {
    return request({
        url: api + '/dsf',
        method: "put",
        data
    })
}
//修改第三方状态
export function putDsfZt(data) {
    return request({
        url: api + '/dsf/judge',
        method: "post",
        data
    })
}
//详情
export function infoDsf(id) {
    return request({
        url: api + `/dsf/${id}`,
        method: "get"
    })
}
//删除
export function delDsf(ids) {
    return request({
        url: api + `/dsf?ids=${ids}`,
        method: "delete"
    })
}