<!-- 增删改查基础模板 -->
<script setup>
import { ref, getCurrentInstance, onMounted } from "vue";
import {
  getDsfList,
  addDsf,
  putDsf,
  infoDsf,
  putDsfZt,
  delDsf
} from "@/api/basicsmanage/thirdParty.js";
const { proxy } = getCurrentInstance();
const { D_BZ_DSFFWLX, D_BZ_DSFSYZT } = proxy.$dict(
  "D_BZ_DSFFWLX",
  "D_BZ_DSFSYZT"
);
const keyCount = ref(0); //tabel组件刷新值
const form = ref({}); //新增表单
const tableData = ref([]); //表格数据
const total = ref(0);
const chackAdd = ref(false); //新增修改切换
const loading = ref(false); //新增保存按钮截流
const ids = ref([]); //表格选中id集合
const searchBox = ref(null); //搜索盒子
const loadingTable = ref(true); //表格加载状态
const tableHeight = ref(); // 表格高度
const dialogFormVisible = ref(false);
const title = ref("新增"); //弹窗标题
const elform = ref(null); //新增表单容器
const listQuery = ref({
  pageCurrent: 1,
  pageSize: 10
}); //搜索表单
//表单验证
const rules = ref({
  xtmc: [{ required: true, message: "请填写系统名称", trigger: "change" }],
  fwlx: [{ required: true, message: "请选择服务类型", trigger: "change" }],
  zrrxm: [{ required: true, message: "请填写责任人姓名", trigger: "change" }]
});
function shFn(row) {
  proxy
    .$confirm("是否通过审核", "提示", {
      distinguishCancelAndClose: true,
      confirmButtonText: "通过",
      cancelButtonText: "不通过"
    })
    .then(() => {
      putDsfZt({ id: row.id, zt: "02" }).then(() => {
        proxy.$message({
          message: "审核已通过",
          type: "success"
        });
        getListData();
      });
    })
    .catch((action) => {
      if(action === 'cancel'){
        putDsfZt({ id: row.id, zt: "03" }).then(() => {
          proxy.$message({
            message: "审核未通过",
            type: "warning"
          });
          getListData();
        });
      }else{
        proxy.$message.info("审核已取消");
      }
    });
}
function tyFn(row) {
  proxy
    .$confirm("确定要停用", "警告", {
      type: "warning"
    })
    .then(() => {
      putDsfZt({ id: row.id, zt: "04" }).then(() => {
        proxy.$message({
          message: "停用成功",
          type: "success"
        });
        getListData();
      });
    })
    .catch(() => {});
}

// 获取列表
function getListData() {
  tableData.value = [];
  loadingTable.value = true;
  getDsfList(listQuery.value).then((res) => {
    tableData.value = res.records;
    total.value = res.total;
    loadingTable.value = false;
  }).catch(()=>{
    loadingTable.value = false;
  });
}
//打开新增弹窗
function add() {
  chackAdd.value = true;
  dialogFormVisible.value = true;
}
//关闭弹窗
function close() {
  dialogFormVisible.value = false;
  form.value = {};
}
//提交
function submit() {
  elform.value.validate((valid) => {
    if (valid) {
      loading.value = true;
      setTimeout(() => {
        loading.value = false;
      }, 1500);
      if (chackAdd.value) {
        addDsf(form.value).then(() => {
          proxy.$message({
            type: "success",
            message: "新增成功"
          });
          close();
          getListData();
        });
      } else {
        putDsf(form.value).then(() => {
          proxy.$message({
            type: "success",
            message: "修改成功"
          });
          close();
          getListData();
        });
      }
    }
  });
}
//修改
function update(row) {
  infoDsf(row.id).then((res) => {
    form.value = res;
    chackAdd.value = false;
    form.value = row;
    title.value = "修改";
    dialogFormVisible.value = true;
  });
}
//批量数据
const handleSelectionChange = (val) => {
  ids.value = [];
  if (val) {
    val.forEach((item) => {
      ids.value.push(item.id);
    });
  }
};
//删除
function delDictItem(row) {
  proxy
    .$confirm("确定要删除", "警告", {
      type: "warning"
    })
    .then(() => {
      delDsf([row.id]).then(() => {
        proxy.$message({
          type: "success",
          message: "删除成功"
        });
        getListData();
      });
    })
    .catch(() => {
      proxy.$message.info("已取消");
    });
}
//批量删除
function batchDelete() {
  proxy
    .$confirm("确定要删除", "警告", {
      type: "warning"
    })
    .then(() => {
      delDsf(ids.value).then((res) => {
        proxy.$message({
          message: "删除成功",
          type: "success"
        });
        getListData();
      });
    })
    .catch(() => {
      proxy.$message.info("已取消");
    });
}
//点击查询
const handleFilter = () => {
  listQuery.value.pageCurrent = 1;
  getListData();
};
//点击重置
const reset = () => {
  listQuery.value = {
    pageCurrent: 1,
    pageSize: 10
  };
  getListData();
};
// 表格高度计算
const tabHeightFn = () => {
 tableHeight.value = window.innerHeight - searchBox.value.offsetHeight - 240;
};
/**
 * pageSize 改变触发
 */
const handleSizeChange = (currentSize) => {
  listQuery.value.pageSize = currentSize;
  getListData();
};

/**
 * 页码改变触发
 */
const handleCurrentChange = (currentPage) => {
  listQuery.value.pageCurrent = currentPage;
  getListData();
};
onMounted(() => {
  getListData();
  tabHeightFn();
  window.onresize = function () {
    tabHeightFn();
  };
  proxy.mittBus.on("mittFn", (data) => {
    keyCount.value = data;
  });
});
</script>

<template>
  <div>
    <div class="titleBox">
      <div class="title">第三方服务</div>
      <div class="btnBox">
        <el-button type="primary" @click="add">
          <el-icon style="vertical-align: middle">
            <CirclePlus />
          </el-icon>
          <span style="vertical-align: middle">新增</span>
        </el-button>
        <el-button
          @click="batchDelete"
          :disabled="ids.length == 0"
          typeof="danger"
        >
          <el-icon style="vertical-align: middle">
            <Delete />
          </el-icon>
          <span style="vertical-align: middle">批量删除</span>
        </el-button>
      </div>
    </div>
    <div class="searchBox" ref="searchBox">
      <el-form :model="listQuery" :inline="true">
        <el-form-item label="系统名称">
          <el-input
            v-model="listQuery.xtmc"
            placeholder="请输入系统名称"
            clearable
          ></el-input>
        </el-form-item>
        <el-form-item label="服务类型">
          <el-select style="width: 100%" v-model="listQuery.fwlx">
            <el-option
              v-for="dict in D_BZ_DSFFWLX"
              :key="dict.value"
              :label="dict.label"
              :value="dict.value"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="责任人姓名">
          <el-input
            v-model="listQuery.zrrxm"
            placeholder="请输入责任人姓名"
            clearable
          ></el-input>
        </el-form-item>
        <el-form-item>
          <el-button @click="handleFilter"> 查询 </el-button>
          <el-button @click="reset()"> 重置 </el-button>
        </el-form-item>
      </el-form>
    </div>
    <div class="tabBox">
      <el-table
        :data="tableData"
        border
        row-key="id"
        style="width: 100%"
        :key="keyCount"
        :height="tableHeight"
        v-loading="loadingTable"
        element-loading-background="rgba(0,0,0,0.3)"
        element-loading-text="数据加载中。。"
        @selection-change="handleSelectionChange"
      >
        <el-table-column type="selection" width="40" align="center" />
        <el-table-column label="序号" type="index" align="center" width="60" />
        <el-table-column label="系统名称" prop="xtmc" align="center" />
        <el-table-column label="服务类型" prop="fwlx" align="center">
          <template #default="{ row }">
            <dict-tag :options="D_BZ_DSFFWLX" :value="row.fwlx" :tag="false" />
          </template>
        </el-table-column>
        <el-table-column label="责任人" prop="zrrxm" align="center" />
        <el-table-column label="责任人联系电话" prop="zrrlxdh" align="center" />
        <el-table-column label="使用状态" prop="zt" align="center">
          <template #default="{ row }">
            <dict-tag :options="D_BZ_DSFSYZT" :value="row.zt" :tag="true" />
          </template>
        </el-table-column>
        <el-table-column
          label="操作"
          align="center"
          fixed="right"
          width="250px"
        >
          <template #default="{ row }">
            <template v-if="row.zt === '01'">
              <el-button @click="shFn(row)" size="small">审核</el-button>
            </template>
            <template v-if="row.zt === '02'">
              <el-button @click="tyFn(row)" size="small">停用</el-button>
            </template>
            <el-button @click="update(row)" size="small">修改</el-button>

            <el-button @click="delDictItem(row)" type="danger" size="small"
              >删除</el-button
            >
          </template>
        </el-table-column>
      </el-table>
      <div class="fenye" :style="{ top: tableHeight + 'px' }">
        <el-pagination
          class="pagination"
          @size-change="handleSizeChange"
          @current-change="handleCurrentChange"
          :current-page="listQuery.pageCurrent"
          :page-sizes="[10, 20, 50, 100]"
          :page-size="listQuery.pageSize"
          layout="total, sizes, prev, pager, next, jumper"
          :total="total"
        >
        </el-pagination>
      </div>
    </div>
    <div class="dialog" v-if="dialogFormVisible">
      <div class="head_box">
        <span class="title">{{ title }}</span>
        <div>
          <el-button
            :loading="loading"
            type="primary"
            size="small"
            @click="submit"
            >保存</el-button
          >
          <el-button size="small" @click="close">关闭</el-button>
        </div>
      </div>
      <el-form
        ref="elform"
        :model="form"
        :rules="rules"
        :inline="true"
        label-position="top"
      >
        <el-form-item label="系统名称" prop="xtmc">
          <el-input v-model="form.xtmc" placeholder="请填写系统名称"></el-input>
        </el-form-item>
        <el-form-item label="服务类型" prop="fwlx">
          <el-select style="width: 100%" v-model="form.fwlx">
            <el-option
              v-for="dict in D_BZ_DSFFWLX"
              :key="dict.value"
              :label="dict.label"
              :value="dict.value"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="责任人" prop="zrrxm">
          <el-input
            v-model="form.zrrxm"
            placeholder="请填写责任人姓名"
          ></el-input>
        </el-form-item>

        <el-form-item label="责任人联系电话" prop="zrrlxdh">
          <el-input
            v-model="form.zrrlxdh"
            placeholder="请填写责任人联系电话"
          ></el-input>
        </el-form-item>
        <el-form-item label="过期时间" prop="gqsj">
          <el-date-picker
            style="width: 100%"
            v-model="form.gqsj"
            type="date"
            placeholder="请选择过期时间"
            format="YYYY-MM-DD"
            value-format="YYYY-MM-DD"
          ></el-date-picker>
        </el-form-item>

        <el-form-item prop="bz" label="备注" style="width: 100%">
          <el-input
            v-model="form.bz"
            placeholder="请输入关键字"
            show-word-limit
            type="textarea"
          />
        </el-form-item>
      </el-form>
    </div>
  </div>
</template>
<style lang="scss" scoped>
@import "~@/assets/css/layout.scss";
@import "~@/assets/css/element-plus.scss";
</style>
